==> component-layout-1.0.0.tgz: package/icode.config.js <==
const path = require('path');
const projectRoot = process.cwd();
module.exports = {
  layoutRoot: path.join(__dirname, 'src'),
  templatePath: path.join(__dirname, 'src/index.ejs'),
  publicPath: '/', // 子应用base路径， 默认为包名
  outputPath: path.join(projectRoot, './dist'), // 打包文件输出地址；配置值时，基于项目根目录，默认为：'./libDist'
  isBundleAnalyzerPlugin: false,
  packEntry: {
    button: './src/index',
  },
  // lessVariables: {
  //   'primary-color': '#ff0000',
  //   'primaryColor': '#ff0000',
  //   '@primary-color': '#000'
  // },
  webpackConfig: (config, options) => {
    config.resolve.alias = {
      '@icode-run/component-layout': path.join(__dirname, 'src'),
      'Component': path.join(projectRoot, './src'),
      '@icode-run/theme': path.join(__dirname, './node_modules/@icode-run/theme/src'),
    };

    config.devServer.proxy = {
      '/web': {
        target: 'http://www.icoderun.com',
        changeOrigin: true,
      },
      // '/lowcodeApi': {
      //   target: 'http://www.icoderun.com',
      //   changeOrigin: true,
      // },
      '/staticImages': {
        target: 'http://www.icoderun.com',
        changeOrigin: true,
      }
    };

    config.plugins.push(
      new options.moduleFederationPlugin({
        name: '@icode-run',
        filename: 'remoteEntry.js',
        library: { type: 'var', name: '@icode-run' },
        exposes: {},
        shared: {
          react: { singleton: true },
          'react-dom': { singleton: true },
        },
      }),
      new options.monacoWebpackPlugin({
        languages: ['javascript', 'css', 'json']
      })
    );

    return config;
  },
};

==> component-layout-1.0.1.tgz: package/icode.config.js <==
const path = require('path');
const projectRoot = process.cwd();
module.exports = {
  layoutRoot: path.join(__dirname, 'src'),
  templatePath: path.join(__dirname, 'src/index.ejs'),
  publicPath: '/', // 子应用base路径， 默认为包名
  outputPath: path.join(projectRoot, './dist'), // 打包文件输出地址；配置值时，基于项目根目录，默认为：'./libDist'
  isBundleAnalyzerPlugin: false,
  packEntry: {
    button: './src/index',
  },
  // lessVariables: {
  //   'primary-color': '#ff0000',
  //   'primaryColor': '#ff0000',
  //   '@primary-color': '#000'
  // },
  webpackConfig: (config, options) => {
    config.resolve.alias = {
      '@icode-run/component-layout': path.join(__dirname),
      'Component': path.join(projectRoot)
    };

    config.devServer.proxy = {
      '/web': {
        target: 'http://www.icoderun.com',
        changeOrigin: true,
      },
      // '/lowcodeApi': {
      //   target: 'http://www.icoderun.com',
      //   changeOrigin: true,
      // },
      '/staticImages': {
        target: 'http://www.icoderun.com',
        changeOrigin: true,
      }
    };

    config.plugins.push(
      new options.moduleFederationPlugin({
        name: '@icode-run',
        filename: 'remoteEntry.js',
        library: { type: 'var', name: '@icode-run' },
        exposes: {},
        shared: {
          react: { singleton: true },
          'react-dom': { singleton: true },
        },
      }),
      new options.monacoWebpackPlugin({
        languages: ['javascript', 'css', 'json']
      })
    );

    return config;
  },
};
